@@ -11,22 +11,23 @@
 
 (unless (defined? '*notcurses*)          ; nrepl.c has notcurses_s7.c (thus *notcurses*) built-in
   (load "notcurses_s7.so" (inlet 'init_func 'notcurses_s7_init)))
+(unless (defined? 'nccell_make)        (define nccell_make cell_make))
+(unless (defined? 'nccell_gcluster)    (define nccell_gcluster cell_gcluster))
+(unless (defined? 'nccell_channels)    (define nccell_channels cell_channels))
+(unless (defined? 'nccell_stylemask)   (define nccell_stylemask cell_stylemask))
+(unless (defined? 'nccells_double_box) (define nccells_double_box cells_double_box))
 
-(if (and (defined? 'NOTCURSES_VERNUM_MAJOR)
-	 (>= NOTCURSES_VERNUM_MAJOR 2)
-	 (>= NOTCURSES_VERNUM_MINOR 1))
-    (begin
-      (define ncdirect_fg ncdirect_set_fg_rgb)
-      (define ncdirect_bg ncdirect_set_bg_rgb))
-    (begin
-      (define ncdirect_fg ncdirect_fg_rgb)
-      (define ncdirect_bg ncdirect_bg_rgb)))
+(unless (defined? 'CELL_FGDEFAULT_MASK) (define CELL_FGDEFAULT_MASK NC_FGDEFAULT_MASK))
+(unless (defined? 'CELL_BGDEFAULT_MASK) (define CELL_BGDEFAULT_MASK NC_BGDEFAULT_MASK))
+
+(unless (defined? 'notcurses_getc) (define (notcurses_getc a b c d) (notcurses_get a b d)))
 
 (define (drop-into-repl call e)
   ((*nrepl* 'run) "break>" (object->string call) e))
 
 (define (display-debug-info cint) #f) ; replaced later
 (define (remove-watcher var) #f)
+(define (nrepl-lookup symbol) (((*nrepl* 'top-level-let) 'run-let) symbol))
 
 (define (debug.scm-init)
   (set! (debug-repl)
@@ -67,12 +68,11 @@
 
 (unless (defined? '*nrepl*)
   (define *nrepl*
-    (let* ((ncd #f)
-	   (nc #f)
+    (let* ((nc #f)
 	   (nc-cols 0)
 	   (nc-rows 0)
 	   (status-rows 3)
-	   (status-cells (vector (cell_make) (cell_make) (cell_make) (cell_make) (cell_make) (cell_make)))
+	   (status-cells (vector (nccell_make) (nccell_make) (nccell_make) (nccell_make) (nccell_make) (nccell_make)))
 	   (statp #f)
 	   (statp-row 0)
 	   (recursor #f)
@@ -83,6 +83,7 @@
 	      :ncp-let #f
 	      :display-status #f
 	      :status-text ""
+	      :run-let #f
 
 	      :s7-version (lambda () (*s7* 'version))
 
@@ -261,13 +262,13 @@
 
       (define (statp-set-bg-color r g b)
 	;; (statp-bg-set-color 0.85 0.85 0.85): light gray background
-	(let ((c1 (cell_make)))
+	(let ((c1 (nccell_make)))
 	  (let ((color (logior (ash (floor (* r 256)) 16)
 			       (ash (floor (* g 256)) 8)
 			       (floor (* b 256)))))
-	    (set! (cell_gcluster c1) (char->integer #\space))
-	    (set! (cell_channels c1) (logior CELL_FGDEFAULT_MASK CELL_BGDEFAULT_MASK color)))
-	  (set! (cell_stylemask c1) 0)
+	    (set! (nccell_gcluster c1) (char->integer #\space))
+	    (set! (nccell_channels c1) (logior CELL_FGDEFAULT_MASK CELL_BGDEFAULT_MASK color)))
+	  (set! (nccell_stylemask c1) 0)
 	  (ncplane_set_base_cell statp c1)
 	  (notcurses_render nc)
 	  c1))
@@ -291,17 +292,17 @@
 
       ;; -------- red text --------
       (define (red c)
-	(let ((c1 (cell_make)))
-	  (set! (cell_gcluster c1) (char->integer c))
-	  (set! (cell_channels c1)  (logior CELL_FGDEFAULT_MASK #xff000000000000))
-	  (set! (cell_stylemask c1) 0)
+	(let ((c1 (nccell_make)))
+	  (set! (nccell_gcluster c1) (char->integer c))
+	  (set! (nccell_channels c1)  (logior CELL_FGDEFAULT_MASK #xff000000000000))
+	  (set! (nccell_stylemask c1) 0)
 	  c1))
 
       (define (normal c)
-	(let ((c1 (cell_make)))
-	  (set! (cell_gcluster c1) (char->integer c))
-	  (set! (cell_channels c1)  0)
-	  (set! (cell_stylemask c1) 0)
+	(let ((c1 (nccell_make)))
+	  (set! (nccell_gcluster c1) (char->integer c))
+	  (set! (nccell_channels c1)  0)
+	  (set! (nccell_stylemask c1) 0)
 	  c1))
 
       (define red-error (let ((v (make-vector 5)))
@@ -345,15 +346,14 @@
 
 	  (define (move-cursor y x)   ; this was (format *stderr* "~C[~D;~DH" #\escape y x) in repl.scm
 	    (notcurses_refresh nc)    ; needed in 1.7.1, not in 1.6.11
-
-	    (ncdirect_cursor_move_yx ncd
+	    (notcurses_cursor_enable nc 
 				     (max header-row (+ y ncp-row))
 				     (if (and wc (= y (+ watch-row 1)))
 					 (min (- watch-col 1) (+ x ncp-col))
 					 (+ x ncp-col))))
-
+	  (set! (top-level-let :run-let) (curlet))
 	  (when header
-	    (set! hc-cells (vector (cell_make) (cell_make) (cell_make) (cell_make) (cell_make) (cell_make)))
+	    (set! hc-cells (vector (nccell_make) (nccell_make) (nccell_make) (nccell_make) (nccell_make) (nccell_make)))
 	    (let ((newline-pos (char-position #\newline header)))
 	      (if newline-pos
 		  (let loop ((str (substring header (+ newline-pos 1)))
@@ -366,7 +366,7 @@
 				(nlen (length newlines)))
 			    (set! hc (ncplane_new nc (+ 3 nlen) ncp-cols 0 0 (c-pointer 0)))
 			    (ncplane_cursor_move_yx hc 0 0)
-			    (cells_double_box hc 0 0 (hc-cells 0) (hc-cells 1) (hc-cells 2) (hc-cells 3) (hc-cells 4) (hc-cells 5))
+			    (nccells_double_box hc 0 0 (hc-cells 0) (hc-cells 1) (hc-cells 2) (hc-cells 3) (hc-cells 4) (hc-cells 5))
 			    (ncplane_box hc (hc-cells 0) (hc-cells 1) (hc-cells 2) (hc-cells 3) (hc-cells 4) (hc-cells 5) (+ 1 nlen) (- nc-cols 1) 0)
 			    (set! header-strings (make-vector nlen))
 			    (do ((i 0 (+ i 1))
@@ -384,7 +384,7 @@
 		  (begin
 		    (set! hc (ncplane_new nc 3 ncp-cols 0 0 (c-pointer 0)))
 		    (ncplane_cursor_move_yx hc 0 0)
-		    (cells_double_box hc 0 0 (hc-cells 0) (hc-cells 1) (hc-cells 2) (hc-cells 3) (hc-cells 4) (hc-cells 5))
+		    (nccells_double_box hc 0 0 (hc-cells 0) (hc-cells 1) (hc-cells 2) (hc-cells 3) (hc-cells 4) (hc-cells 5))
 		    (ncplane_box hc (hc-cells 0) (hc-cells 1) (hc-cells 2) (hc-cells 3) (hc-cells 4) (hc-cells 5) 2 (- nc-cols 1) 0)
 		    (ncplane_putstr_yx hc 1 1 (make-string (- nc-cols 5) #\space))
 		    (set! header-strings (vector header))
@@ -400,10 +400,10 @@
 	    (ncplane_move_below ncp statp) ; statp always displayed with ncplanes sliding underneath conceptually
 
 	    ;; opaque plane
-	    (let ((c1 (cell_make)))
-	      (set! (cell_gcluster c1) (char->integer #\space))
-	      (set! (cell_channels c1) 0)
-	      (set! (cell_stylemask c1) 0)
+	    (let ((c1 (nccell_make)))
+	      (set! (nccell_gcluster c1) (char->integer #\space))
+	      (set! (nccell_channels c1) 0)
+	      (set! (nccell_stylemask c1) 0)
 	      (ncplane_set_base_cell ncp c1)
 	      (notcurses_render nc))
 
@@ -696,17 +696,17 @@
 				   (var-str (format #f "~A: ~A" var (substring str (+ pos 9)))))
 
 			      (unless wc
-				(set! wc-cells (vector (cell_make) (cell_make) (cell_make) (cell_make) (cell_make) (cell_make)))
+				(set! wc-cells (vector (nccell_make) (nccell_make) (nccell_make) (nccell_make) (nccell_make) (nccell_make)))
 				(set! watch-row header-row)
 				(set! watch-col (floor (* 0.618 nc-cols))) ; ah the good old days
 				(set! watch-cols (- nc-cols watch-col))
 				(set! wc (ncplane_new nc watch-rows watch-cols watch-row watch-col (c-pointer 0)))
-				(cells_double_box wc 0 0 (wc-cells 0) (wc-cells 1) (wc-cells 2) (wc-cells 3) (wc-cells 4) (wc-cells 5))
+				(nccells_double_box wc 0 0 (wc-cells 0) (wc-cells 1) (wc-cells 2) (wc-cells 3) (wc-cells 4) (wc-cells 5))
 				(ncplane_box wc (wc-cells 0) (wc-cells 1) (wc-cells 2) (wc-cells 3) (wc-cells 4) (wc-cells 5) (- watch-rows 1) (- watch-cols 1) 0)
-				(let ((c1 (cell_make)))
-				  (set! (cell_gcluster c1) (char->integer #\space))
-				  (set! (cell_channels c1) 0)   ; opaque apparently
-				  (set! (cell_stylemask c1) 0)
+				(let ((c1 (nccell_make)))
+				  (set! (nccell_gcluster c1) (char->integer #\space))
+				  (set! (nccell_channels c1) 0)   ; opaque apparently
+				  (set! (nccell_stylemask c1) 0)
 				  (ncplane_set_base_cell wc c1)
 				  (notcurses_render nc)))
 
@@ -980,8 +980,11 @@
 		      (mouse-col #f)
 		      (mouse-row #f)
 		      (repl-done #f)
-		      (selection #f)
-		      (control-key (ash 1 33)))    ; notcurses getc returns 32 bits
+		      (selection "")
+                      (previously-selected #f)
+                      (just-selected #f)
+		      (control-key (ash 1 33))
+                      (meta-key (ash 1 34)))    ; notcurses get returns 32 bits
 
 		  (set! (top-level-let 'ncp-let) (curlet))
 		  (set! display-debug-info local-debug-info)
@@ -1162,67 +1165,123 @@
 		      ((= i 256))
 		    (set! (keymap i) normal-char))
 
-		  (set! (keymap (char->integer #\escape))
+                  (define (prepend-to-selection new-text)
+                    (unless (zero? (length new-text))
+                      (set! selection (if previously-selected (append new-text selection)
+					  new-text))
+                      (set! just-selected #t)))
+                  (define (append-to-selection new-text)
+                    (unless (zero? (length new-text))
+                      (set! selection (if previously-selected (append selection new-text)
+					  new-text))
+                      (set! just-selected #t)))
+                  (define (char-separator? c)
+                    (char-position c " ()`',\"#"))
+                  (define (word-back-x) ;; some of these are courtesy of Elijah Stone
+                    (let loop ((col (max (bols row) (- col 1))))
+                      (if (= col (bols row))
+			  col
+			  (if (char-separator? (ncplane_contents ncp row col 1 1))
+			      (loop (- col 1))
+			      (let loop ((col col))
+				(if (= col (bols row))
+				    col
+				    (if (char-separator? (ncplane_contents ncp row (- col 1) 1 1))
+					col
+					(loop (- col 1)))))))))
+                  (define (word-forward-x)
+                    (let loop ((col (min (eols row) (+ col 1))))
+                      (if (= col (eols row))
+			  col
+			  (if (char-separator? (ncplane_contents ncp row col 1 1))
+			      (loop (+ col 1))
+			      (let loop ((col col))
+				(if (= col (eols row))
+				    col
+				    (if (char-separator? (ncplane_contents ncp row col 1 1))
+					col
+					(loop (+ col 1)))))))))
+		  
+                  (set! (keymap (+ meta-key (char->integer #\B)))
+			(set! (keymap (+ meta-key (char->integer #\b)))
+			      (lambda (c)
+				(set! col (word-back-x)))))
+		  
+                  (set! (keymap (+ meta-key (char->integer #\C)))
+			(set! (keymap (+ meta-key (char->integer #\c)))
+			      (lambda (c)
+				(do ((len (- (eols row) col))
+				     (cur-line (ncplane_contents ncp row col 1 (- (eols row) col)))
+				     (i 0 (+ i 1)))
+				    ((or (= i len)
+					 (char-alphabetic? (cur-line i)))
+				     (when (< i len)
+				       (set! (cur-line i) (char-upcase (cur-line i)))
+				       (nc-display row col cur-line)
+				       (notcurses_refresh nc)
+				       (do ((k (+ i 1) (+ k 1)))
+					   ((or (>= k len)
+						(not (or (char-alphabetic? (cur-line k))
+							 (char-numeric? (cur-line k)))))
+					    (set! col (min (eols row) (+ col k)))))))))))
+		  
+                  (set! (keymap (+ meta-key (char->integer #\D)))
+			(set! (keymap (+ meta-key (char->integer #\d)))
+			      (lambda (c)
+				(let ((newcol (word-forward-x)))
+				  (append-to-selection (ncplane_contents ncp row col 1 (- newcol col)))
+				  (nc-display row col (ncplane_contents ncp row newcol 1 (- (eols row) newcol)))
+				  (nc-display row (- (eols row) (- newcol col)) (make-string (- newcol col) #\space))
+				  (set! (eols row) (- (eols row) (- newcol col)))))))
+		  
+                  (set! (keymap (+ meta-key (char->integer #\F)))
+			(set! (keymap (+ meta-key (char->integer #\f)))
+			      (lambda (c)
+				(set! col (word-forward-x)))))
+		  
+                  (set! (keymap (+ meta-key (char->integer #\L)))
+			(set! (keymap (+ meta-key (char->integer #\l)))
+			      (lambda (c)
+				(do ((len (- (eols row) col))
+				     (cur-line (ncplane_contents ncp row col 1 (- (eols row) col)))
+				     (i 0 (+ i 1)))
+				    ((or (= i len)
+					 (char-alphabetic? (cur-line i)))
+				     (when (< i len)
+				       (do ((k i (+ k 1)))
+					   ((or (= k len)
+						(not (char-alphabetic? (cur-line k))))
+					    (nc-display row col cur-line)
+					    (notcurses_refresh nc)
+					    (set! col (+ col k)))
+					 (set! (cur-line k) (char-downcase (cur-line k))))))))))
+		  
+                  (set! (keymap (+ meta-key (char->integer #\U)))
+			(set! (keymap (+ meta-key (char->integer #\u)))
+			      (lambda (c)
+				(do ((len (- (eols row) col))
+				     (cur-line (ncplane_contents ncp row col 1 (- (eols row) col)))
+				     (i 0 (+ i 1)))
+				    ((or (= i len)
+					 (char-alphabetic? (cur-line i)))
+				     (when (< i len)
+				       (do ((k i (+ k 1)))
+					   ((or (= k len)
+						(not (char-alphabetic? (cur-line k))))
+					    (nc-display row col cur-line)
+					    (notcurses_refresh nc)
+					    (set! col (+ col k)))
+					 (set! (cur-line k) (char-upcase (cur-line k))))))))))
+		  
+                  (set! (keymap (+ meta-key (char->integer #\<)))
 			(lambda (c)
-			  ;; these are the Meta key handlers
-			  (let ((k (notcurses_getc nc (c-pointer 0) (c-pointer 0) ni)))
-
-			    (case (integer->char k)
-			      ((#\C #\c)
-			       (do ((len (- (eols row) col))
-				    (cur-line (ncplane_contents ncp row col 1 (- (eols row) col)))
-				    (i 0 (+ i 1)))
-				   ((or (= i len)
-					(char-alphabetic? (cur-line i)))
-				    (when (< i len)
-				      (set! (cur-line i) (char-upcase (cur-line i)))
-				      (nc-display row col cur-line)
-				      (notcurses_refresh nc)
-				      (do ((k (+ i 1) (+ k 1)))
-					  ((or (>= k len)
-					       (not (or (char-alphabetic? (cur-line k))
-							(char-numeric? (cur-line k)))))
-					   (set! col (min (eols row) (+ col k)))))))))
-
-			      ((#\L #\l)
-			       (do ((len (- (eols row) col))
-				    (cur-line (ncplane_contents ncp row col 1 (- (eols row) col)))
-				    (i 0 (+ i 1)))
-				   ((or (= i len)
-					(char-alphabetic? (cur-line i)))
-				    (when (< i len)
-				      (do ((k i (+ k 1)))
-					  ((or (= k len)
-					       (not (char-alphabetic? (cur-line k))))
-					   (nc-display row col cur-line)
-					   (notcurses_refresh nc)
-					   (set! col (+ col k)))
-					(set! (cur-line k) (char-downcase (cur-line k))))))))
-
-			      ((#\U #\u)
-			       (do ((len (- (eols row) col))
-				    (cur-line (ncplane_contents ncp row col 1 (- (eols row) col)))
-				    (i 0 (+ i 1)))
-				   ((or (= i len)
-					(char-alphabetic? (cur-line i)))
-				    (when (< i len)
-				      (do ((k i (+ k 1)))
-					  ((or (= k len)
-					       (not (char-alphabetic? (cur-line k))))
-					   (nc-display row col cur-line)
-					   (notcurses_refresh nc)
-					   (set! col (+ col k)))
-					(set! (cur-line k) (char-upcase (cur-line k))))))))
-
-			      ((#\<)
-			       (set-row 0)
-			       (set-col (bols 0)))
-
-			      ((#\>)
-			       (set-row ncp-max-row)
-			       (set-col (bols ncp-max-row)))
-
-			      )))) ; end Meta keys
+			  (set-row 0)
+			  (set-col (bols 0))))
+		  
+                  (set! (keymap (+ meta-key (char->integer #\>)))
+			(lambda (c)
+			  (set-row ncp-max-row)
+			  (set-col (bols ncp-max-row))))
 
 		  (set! (keymap (char->integer #\tab)) tab)
 
@@ -1273,9 +1332,9 @@
 			  (ncplane_move_yx ncp ncp-row ncp-col)
 			  (reprompt row)))
 
-		  (set! (keymap (+ control-key (char->integer #\K)))
+                  (set! (keymap (+ control-key (char->integer #\K)))
 			(lambda (c)
-			  (set! selection (ncplane_contents ncp row col 1 (- (eols row) col)))
+			  (append-to-selection (ncplane_contents ncp row col 1 (- (eols row) col)))
 			  (nc-display row col (make-string (- (eols row) col) #\space))
 			  (set! (eols row) col)))
 
@@ -1303,14 +1362,14 @@
 				(set! bols (copy bols (make-int-vector ncp-rows)))
 				(set! eols (copy eols (make-int-vector ncp-rows))))
 
-				(do ((i (+ ncp-max-row 1) (- i 1)))
-				    ((= i (+ row 1))
-				     (set! ncp-max-row (+ ncp-max-row 1)))
-				  (let ((contents (ncplane_contents ncp (- i 1) 0 1 (eols (- i 1)))))
-				    (clear-line i)
-				    (nc-display i 0 contents)) ; should this be indented?
-				  (set! (eols i) (eols (- i 1)))
-				  (set! (bols i) (bols (- i 1)))))
+			      (do ((i (+ ncp-max-row 1) (- i 1)))
+				  ((= i (+ row 1))
+				   (set! ncp-max-row (+ ncp-max-row 1)))
+				(let ((contents (ncplane_contents ncp (- i 1) 0 1 (eols (- i 1)))))
+				  (clear-line i)
+				  (nc-display i 0 contents)) ; should this be indented?
+				(set! (eols i) (eols (- i 1)))
+				(set! (bols i) (bols (- i 1)))))
 
 			    (nc-display row col (make-string (- (eols row) col) #\space))
 			    (set! (eols row) col)
@@ -1346,6 +1405,23 @@
 			      (if (< cur (eols row))
 				  (set-col (+ cur 1)))))))
 
+                  (set! (keymap (+ control-key (char->integer #\U)))
+			(lambda (c)
+			  (prepend-to-selection (ncplane_contents ncp row (bols row) 1 (- col (bols row))))
+			  (nc-display row (bols row) (ncplane_contents ncp row col 1 (- (eols row) col)))
+			  (nc-display row (- (eols row) (- col (bols row))) (make-string (- col (bols row)) #\space))
+			  (set! (eols row) (- (eols row) (- col (bols row))))
+			  (set! col (bols row))))
+		  
+                  (set! (keymap (+ control-key (char->integer #\W)))
+			(lambda (c)
+			  (let ((newcol (word-back-x)))
+			    (prepend-to-selection (ncplane_contents ncp row newcol 1 (- col newcol)))
+			    (nc-display row newcol (ncplane_contents ncp row col 1 (- (eols row) col)))
+			    (nc-display row (- (eols row) (- col newcol)) (make-string (- col newcol) #\space))
+			    (set! (eols row) (- (eols row) (- col newcol)))
+			    (set! col newcol))))
+		  
 		  (set! (keymap (+ control-key (char->integer #\Y)))
 			(lambda (c)
 			  (when (string? selection)
@@ -1358,7 +1434,7 @@
 				       (> (length trailing) 0))
 				  (nc-display row (+ col (length selection)) trailing)))
 			    (set! (eols row) (+ (eols row) (length selection)))
-			    (set-col (eols row)))))
+			    (set-col (+ col (length selection))))))
 
 		  (set! (keymap NCKEY_LEFT)       ; arrow keys
 			(lambda (c)
@@ -1480,8 +1556,15 @@
 			  (when recursor
 			    (recover-previous-layout))
 
+                          (set! previously-selected just-selected)
+                          (set! just-selected #f)
+			  
 			  (let* ((c (notcurses_getc nc (c-pointer 0) (c-pointer 0) ni))
-				 (func (hash-table-ref keymap (if (ncinput_ctrl ni) (+ c control-key) c))))
+                                 (c (if (= c (char->integer #\escape))
+					(logior meta-key (notcurses_getc nc (c-pointer 0) (c-pointer 0) ni))
+					c))
+				 (func (hash-table-ref keymap (logior c (if (ncinput_ctrl ni) control-key 0)
+								      (if (ncinput_alt ni) meta-key 0)))))
 
 			    (if (procedure? func)
 				(catch #t
@@ -1624,10 +1707,9 @@
 		  (string=? (getenv "TERM") "dumb")))  ; no vt100 codes -- emacs subjob for example
 	    (emacs-repl)
 	    (begin
-	      (set! ncd (ncdirect_init (c-pointer 0))) ; version < 2.1 don't pass #f 0 here -- 0 must not be the old default
 	      (let ((noptions (notcurses_options_make)))
 		(set! (notcurses_options_flags noptions) NCOPTION_SUPPRESS_BANNERS)
-		(set! nc (notcurses_init noptions)))
+		(set! nc (notcurses_core_init noptions)))
 	      (notcurses_cursor_enable nc 0 2)
 	      (unless (string-position "rxvt" ((libc-let 'getenv) "TERM"))
 		(notcurses_mouse_enable nc)) ; 0 if ok, -1 if failure
@@ -1636,7 +1718,7 @@
 		(set! nc-rows (car size))
 		(set! statp-row (- nc-rows status-rows)))
 	      (set! statp (ncplane_new nc nc-rows nc-cols 0 0 (c-pointer 0)))
-	      (cells_double_box statp 0 0 (status-cells 0) (status-cells 1) (status-cells 2) (status-cells 3) (status-cells 4) (status-cells 5))
+	      (nccells_double_box statp 0 0 (status-cells 0) (status-cells 1) (status-cells 2) (status-cells 3) (status-cells 4) (status-cells 5))
 	      (ncplane_putstr_yx statp 1 1 (make-string (- nc-cols 5) #\space))
 	      (when (string-position "rxvt" (getenv "TERM"))
 		(ncplane_putstr_yx statp 1 2 (substring "rxvt doesn't support the mouse" 0 (min 30 (- nc-cols 3))))
@@ -1645,7 +1727,9 @@
 
   (with-let *nrepl*
     (start)
-    (run)
+    (if (string=? (notcurses_version) "2.3.17")
+	(run ">" "version 2.3.17 needs this header!") ; surely this is a bug! 2.3.13 seems to be ok
+	(run))
     (stop)))
 
 ;; selection (both ways):
