@@ -2,8 +2,22 @@
 ;;;
 ;;; (load "repl.scm") ((*repl* 'run))
 
-(set! (*s7* 'history-enabled) #f)
 (provide 'repl.scm)
+
+(when (file-exists? ".repl")         ; local (scheme) initialization file for repl
+  (load ".repl"))
+
+(set! (*s7* 'history-enabled) #f)
+
+(unless (defined? 'stderr-buffered)
+  (define stderr-buffered #f))
+
+(define (fformat port . args)
+  (apply format port args)
+  (when (and stderr-buffered
+	     (eq? port *stderr*))
+    (flush-output-port *stderr*)))
+
 (require libc.scm)
 
 (define old-debug (*s7* 'debug))
@@ -221,10 +235,13 @@
 	    
 	    (define new-eval 
 	      (let ((+documentation+ "this is the repl's eval replacement; its default is to use the repl's top-level-let.")
-		    (+signature+ '(values list? let?)))
-		(lambda* (form (e (*repl* 'top-level-let)))
-		  (let-temporarily (((hook-functions *unbound-variable-hook*) (list shell?)))
-		    (let-temporarily (((*s7* 'history-enabled) #t))
+		    (+signature+ '(values #t let?)))
+		(lambda (form . rest) ; use lambda (not lambda*) so we can handle forms like :key
+		  (let ((e (if (pair? rest) 
+			       (car rest)
+			       (*repl* 'top-level-let))))
+		    (let-temporarily (((hook-functions *unbound-variable-hook*) (list shell?)) ; so pwd et al will work
+				      ((*s7* 'history-enabled) #t))
 		      (eval form e))))))
 	    
 	    ;; -------- match parens --------
@@ -336,13 +353,13 @@
 		      text #\escape))
 	    
 	    (define (move-cursor y x)
-	      (format *stderr* "~C[~D;~DH" #\escape y x))
+	      (fformat *stderr* "~C[~D;~DH" #\escape y x))
 
 	    (define (cursor-coords)
 	      (let* ((c (string #\null #\null))
 		     (cc (string->c-pointer c))
 		     (terminal-fd (fileno stdin)))
-		(format *stderr* "~C[6n" #\escape)
+		(fformat *stderr* "~C[6n" #\escape)
 		(do ((b (read terminal-fd cc 1) (read terminal-fd cc 1)))
 		    ((char=? (string-ref c 0) #\escape)))
 		(read terminal-fd cc 1) 
@@ -369,8 +386,8 @@
 		  (set! last-col (car bounds))
 		  (set! last-row (cdr bounds)))))
 	    
-	    ;; to enable mouse click coords (in xterm anyway), (format *stderr* "~C[?9h" #\escape)
-	    ;;    disable: (format *stderr* "~C[?9l" #\escape)
+	    ;; to enable mouse click coords (in xterm anyway), (fformat *stderr* "~C[?9h" #\escape)
+	    ;;    disable: (fformat *stderr* "~C[?9l" #\escape)
 	    ;;    this is X10_MOUSE -- probably better to use SET_ANY_EVENT_MOUSE 1003
 	    ;; while enabled, mouse selection instead sends coords to repl (so it's annoying)
 	    ;;    also it's sticky!  exit repl does not clear this flag so mouse is effectively dead
@@ -381,7 +398,7 @@
 	    
 	    ;; -------- display --------
 	    (define (display-prompt)
-	      (format *stderr* "~A" prompt-string))
+	      (fformat *stderr* "~A" prompt-string))
 	    
 	    (define (new-prompt)
 	      (set! cur-line "")
@@ -434,7 +451,7 @@
 	    
 	    (define (display-lines)
 	      (move-cursor prompt-row 0)
-	      (format *stderr* "~C[J" #\escape)
+	      (fformat *stderr* "~C[J" #\escape)
 	      (let ((len (length cur-line))
 		    (new-line ""))
 		(do ((line-end 0)
@@ -442,66 +459,9 @@
 		    ((> i len))
 		  (set! line-end (end-of-line i))
 		  (set! new-line (string-append new-line (display-line i (min (+ line-end 2) len)))))
-		(format *stderr* "~A" new-line)
+		(fformat *stderr* "~A" new-line)
 		(display-cursor)))
 	    
-	    
-	    ;; -------- help/debugging --------
-	    (define (one-line text)
-	      (if (not (string? text))
-		  text
-		  (let ((ntext (copy text)))
-		    (do ((i 0 (+ i 1)))
-			((= i (length ntext))
-			 ntext)
-		      (if (char=? (ntext i) #\newline) (set! (ntext i) #\|))))))
-	    
-	    (define (help c)
-	      (when (pair? (*repl* 'helpers))
-		(let ((coords (cursor-coords))
-		      (col (floor (/ last-col 2))))
-		  (move-cursor 1 col)
-		  (format *stderr* "+~NC" (- col 2) #\-)
-		  
-		  (do ((i 2 (+ i 1))                      ; put box in top right corner so we don't get trailing output as we scroll
-		       (lst (*repl* 'helpers) (cdr lst)))
-		      ((null? lst))
-		    (let ((str ((car lst) c)))
-		      (move-cursor i col)
-		      (format *stderr* "~C[K| ~A" #\escape (if (> (length str) col) (substring str 0 (- col 1)) str))))
-		  
-		  (move-cursor (+ 2 (length (*repl* 'helpers))) col)
-		  (format *stderr* "+~NC" (- col 2) #\-)
-		  (move-cursor (cdr coords) (car coords)))))
-	    
-	    (define (debug-help)
-	      (set! (*repl* 'helpers)
-		    (list
-		     (lambda (c) 
-		       (let ((cur-char (if (zero? (length cur-line))
-					   #\space
-					   (let ((c (cur-line (max 0 (min cursor-pos (- (length cur-line) 1))))))
-					     (if (char=? c #\newline) #\| c)))))
-			 (format #f "cursor: ~A, ~C, line: ~S"
-				 cursor-pos cur-char
-				 (one-line cur-line))))
-		     (lambda (c)
-		       (format #f "len: ~D, selection: ~S, previous: ~S" 
-			       (length cur-line) 
-			       (one-line selection) 
-			       (if (pair? prev-line) (one-line (cdar prev-line)) ())))
-		     (lambda (c)
-		       (format #f "cur-row: ~A, prompt-row: ~A" 
-			       cur-row 
-			       prompt-row))
-		     (lambda (c)
-		       (format #f "c: ~S ~D, start: ~A, end: ~A" 
-			       c
-			       (char->integer c)	
-			       (start-of-line cursor-pos)	
-			       (end-of-line cursor-pos))))))
-	    
-	    
 	    ;; -------- keymap(s) --------
 	    (define meta-keymap-functions (make-vector 256))
 	    (define keymap-functions (make-vector 256 #f))
@@ -573,7 +533,7 @@
 	      (set! cur-line (string-append cur-line (string #\space #\newline)))
 	      (set! cursor-pos (length cur-line))
 	      (when (= last-row (+ prompt-row cur-row))
-		(format *stderr* "~%")
+		(fformat *stderr* "~%")
 		(set! prompt-row (- prompt-row 1)))
 	      (set! cur-row (+ cur-row 1)))
 	    
@@ -669,7 +629,7 @@
 	    
 	    (set! (keymap-functions C-l) 
 		  (lambda (c)
-		    (format *stderr* "~C[H~C[J" #\escape #\escape)
+		    (fformat *stderr* "~C[H~C[J" #\escape #\escape)
 		    (new-prompt)))
 	    
 	    ;; -------- deletion
@@ -864,7 +824,7 @@
 						 
 				       (if unbound-case
 					   (set! unbound-case #f)
-					   (format *stderr* "~S~%" val))
+					   (fformat *stderr* "~S~%" val))
 				       (eval `(define ,(string->symbol (format #f "<~D>" (+ (length histtop) 1))) ',val) (rootlet))))))
 			       
 			       (lambda (type info)
@@ -877,14 +837,14 @@
 			   
 			   (lambda (type info)
 			     (with-let (unlet)
-			       (format *stderr* "~A:" (red "error"))
+			       (fformat *stderr* "~A:" (red "error"))
 			       (let ((op (*s7* 'print-length)))
 				 (if (< op 32) (set! (*s7* 'print-length) 32))
 				 (if (and (pair? info)
 					  (string? (car info)))
-				     (format *stderr* " ~A" (apply format #f info))
+				     (fformat *stderr* " ~A" (apply format #f info))
 				     (if (not (null? info))
-					 (format *stderr* " ~A" info)))
+					 (fformat *stderr* " ~A" info)))
 				 (if (< op 32) (set! (*s7* 'print-length) op)))
 			       (eval `(define ,(string->symbol (format #f "<~D>" (+ (length histtop) 1))) 'error) (rootlet))
 			       (newline *stderr*))))
@@ -924,7 +884,7 @@
 		    (set! cursor-pos (length cur-line))
 		    (let ((newlines (count-newlines cur-line)))
 		      (when (< last-row (+ prompt-row newlines))
-			(format *stderr* "~NC" (- (+ prompt-row newlines) last-row) #\newline)
+			(fformat *stderr* "~NC" (- (+ prompt-row newlines) last-row) #\newline)
 			(set! prompt-row (- prompt-row newlines)))
 		      (set! cur-row newlines)))))
 
@@ -1016,7 +976,7 @@
 	      ;;   and does not notice in-place edits
 	      ;;   can <cr> get entire expr?
 	      (let ((buf (c-pointer->string (calloc 512 1) 512)))
-		(format *stderr* "> ")
+		(fformat *stderr* "> ")
 		(do ((b (fgets buf 512 stdin) (fgets buf 512 stdin)))
 		    ((zero? (length b))
 		     (#_exit))
@@ -1027,14 +987,14 @@
 			       (= i len))
 			   (when (< i len)
 			     (let ((str (substring buf 0 (- (strlen buf) 1))))
-			       ;(format *stderr* "str: ~S~%" str)
+			       ;(fformat *stderr* "str: ~S~%" str)
 			       (catch #t
 				 (lambda ()
 				   (do ()
 				       ((= (string-length str) 0))
 				     (catch 'string-read-error
 				       (lambda ()
-					 (format *stderr* "~S~%> " (eval-string str (*repl* 'top-level-let)))
+					 (fformat *stderr* "~S~%> " (eval-string str (*repl* 'top-level-let)))
 					 (set! str ""))
 				       (lambda (type info)
 					 (fgets buf 512 stdin)
@@ -1042,7 +1002,7 @@
 				 (lambda (type info)
 				   (set! str "")
 				   (apply format *stderr* info)
-				   (format *stderr* "~%> "))))))))))))
+				   (fformat *stderr* "~%> "))))))))))))
 
 	    ;; -------- rxvt et al --------
 	    (define (terminal-repl file)		
@@ -1162,9 +1122,9 @@
 					 (lambda (type info)
 					   (set! chars 0)
 					   ;(move-cursor prompt-row prompt-col)
-					   (format *stderr* "internal error: ")
+					   (fformat *stderr* "internal error: ")
 					   (apply format *stderr* info)
-					   (format *stderr* "~%line ~A: ~A~%" ((owlet) 'error-line) ((owlet) 'error-code))
+					   (fformat *stderr* "~%line ~A: ~A~%" ((owlet) 'error-line) ((owlet) 'error-code))
 					   (set! chars 0)
 					   (set! ctr 0)
 					   (new-prompt)
@@ -1211,9 +1171,9 @@
 		      
 		      (lambda (type info)
 			;(move-cursor prompt-row prompt-col)
-			(format *stderr* "internal error: ")
+			(fformat *stderr* "internal error: ")
 			(apply format *stderr* info)
-			(format *stderr* "~%line ~A: ~A~%" ((owlet) 'error-line) ((owlet) 'error-code))
+			(fformat *stderr* "~%line ~A: ~A~%" ((owlet) 'error-line) ((owlet) 'error-code))
 			(set! chars 0)
 			(new-prompt))))))))
 
@@ -1254,8 +1214,9 @@
 			  (format p "(define ~S ~W)~%" (car var) (cdr var))))
 		      (*repl* 'top-level-let)))))
       
-      (define (restore-repl) 
-	(set! (*repl* 'top-level-let) (load "save.repl")))  
+      (define* (restore-repl (file "save.repl"))
+	(set! (*repl* 'top-level-let) (sublet (rootlet)))
+	(load file))
       ;; I think this could be a merge rather than a reset by using (with-let top-level-let (load ...))
       
       (set! keymap (repl-let 'keymap))
@@ -1295,12 +1256,24 @@
 	    (set! cursor-pos 0)
 	    (set! prompt-string (format #f "break~NC " depth #\>))
 	    (set! prompt-length (length prompt-string)))
-	  (format *stderr* "break: ~A, C-q to exit break~%" call)
+	  (fformat *stderr* "break: ~A, C-q to exit break~%" call)
 	  ((*repl* 'run)))))))
 
 (define (debug.scm-init)
   (set! ((funclet trace-in) '*debug-repl*) drop-into-repl))
 
+#|
+(define (open-file-with-catch filename)
+  (catch 'io-error ; is this correct?
+    (lambda ()
+      (open-input-file filename))
+    (lambda (type info)
+      (let ((new-filename #f)
+	    (err ((*libc* 'errno)))) ; get libc error indication (might be disk full or no write permission etc)
+	(drop-into-repl (format #f "can't open ~S, ~S" filename ((*libc* 'strerror) err)) (curlet))
+	(and new-filename
+	     (open-file-with-catch new-filename))))))
+|#
 
 (autoload 'lint "lint.scm")
 (autoload 'pretty-print "write.scm")
@@ -1444,7 +1417,7 @@
 	      'no-match
 	      (begin
 		(for-each (lambda (b)
-			    (format *stderr*
+			    (fformat *stderr*
 				    (if (zero? (cdr b)) "~C[1m~A~C[0m: ~S~%"                           ; black if exact match somewhere
 					(if (or (< (cdr b) 2) (not have-orange)) "~C[31m~A~C[0m: ~S~%" ; red for near miss
 					    "~C[38;5;208m~A~C[0m: ~S~%"))                              ; orange for less likely choices
@@ -1464,10 +1437,9 @@
 ;;; --------------------------------------------------------------------------------
 ;;; just a first stab at this -- where to put this code?
 ;;;
-;;; debug-help can be set running via: (((*repl* 'repl-let) 'debug-help))
 
 (define-expansion (repl-debug)
-  `(with-let (inlet :orig (curlet) :line ,(port-line-number) :func __func__)
+  `(with-let (inlet :orig (curlet) :line ,(port-line-number) :func (*function*))
      (format () "line ~D: ~A~{~^ ~A~}~%" 
 	     line (if (pair? func) (car func) func)
 	     (reverse
@@ -1601,7 +1573,7 @@ to post a help string (kinda tedious, but the helper list is aimed more at posti
 	(with-let (sublet (*repl* 'repl-let))
 	  (let ((next (next-char)))
 	    (when (char=? next (integer->char 6)) ; C-f
-	      (format *stderr* "~%load: ")
+	      (fformat *stderr* "~%load: ")
 	      ;; now recursive call: prompt="load: "
 	      (let ((old-prompt (*repl* 'prompt))
 		    (old-cur-line cur-line)
