@@ -1,10 +1,10 @@
 #ifndef S7_H
 #define S7_H
 
-#define S7_VERSION "9.9"
-#define S7_DATE "4-2-2021"
+#define S7_VERSION "9.17"
+#define S7_DATE "6-Sep-2021"
 #define S7_MAJOR_VERSION 9
-#define S7_MINOR_VERSION 8
+#define S7_MINOR_VERSION 17
 
 #include <stdint.h>           /* for int64_t */
 
@@ -23,6 +23,13 @@ typedef double s7_double;
 #endif
 #endif
 
+#if WITH_GMP
+  /* in g++ these includes need to be outside the extern "C" business */
+  #include <gmp.h>
+  #include <mpfr.h>
+  #include <mpc.h>
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -39,6 +46,7 @@ s7_scheme *s7_init(void);
 void s7_free(s7_scheme *sc);
 
 typedef s7_pointer (*s7_function)(s7_scheme *sc, s7_pointer args);   /* that is, obj = func(s7, args) -- args is a list of arguments */
+typedef s7_pointer (*s7_pfunc)(s7_scheme *sc);
 
 s7_pointer s7_f(s7_scheme *sc);                                      /* #f */
 s7_pointer s7_t(s7_scheme *sc);                                      /* #t */
@@ -224,6 +232,7 @@ s7_int s7_list_length(s7_scheme *sc, s7_pointer a);                          /*
 s7_pointer s7_make_list(s7_scheme *sc, s7_int len, s7_pointer init);         /* (make-list len init) */
 s7_pointer s7_list(s7_scheme *sc, s7_int num_values, ...);                   /* (list ...) */
 s7_pointer s7_list_nl(s7_scheme *sc, s7_int num_values, ...);                /* (list ...) arglist should be NULL terminated (more error checks than s7_list) */
+s7_pointer s7_array_to_list(s7_scheme *sc, s7_int num_values, s7_pointer *array); /* array contents -> list */
 s7_pointer s7_reverse(s7_scheme *sc, s7_pointer a);                          /* (reverse a) */
 s7_pointer s7_append(s7_scheme *sc, s7_pointer a, s7_pointer b);             /* (append a b) */
 s7_pointer s7_list_ref(s7_scheme *sc, s7_pointer lst, s7_int num);           /* (list-ref lst num) */
@@ -273,6 +282,7 @@ s7_double s7_random(s7_scheme *sc, s7_pointer state);                       /* (
 s7_pointer s7_random_state(s7_scheme *sc, s7_pointer seed);                 /* (random-state seed) */
 s7_pointer s7_random_state_to_list(s7_scheme *sc, s7_pointer args);         /* (random-state->list r) */
 void s7_set_default_random_state(s7_scheme *sc, s7_int seed, s7_int carry);
+bool s7_is_random_state(s7_pointer p);                                      /* (random-state? p) */
 
 bool s7_is_complex(s7_pointer arg);                                         /* (complex? arg) */
 s7_pointer s7_make_complex(s7_scheme *sc, s7_double a, s7_double b);        /* returns the Scheme object a+bi */
@@ -305,6 +315,7 @@ s7_double s7_float_vector_set(s7_pointer vec, s7_int index, s7_double value);
 s7_pointer s7_make_vector(s7_scheme *sc, s7_int len);                                 /* (make-vector len) */
 s7_pointer s7_make_int_vector(s7_scheme *sc, s7_int len, s7_int dims, s7_int *dim_info);
 s7_pointer s7_make_float_vector(s7_scheme *sc, s7_int len, s7_int dims, s7_int *dim_info);
+s7_pointer s7_make_normal_vector(s7_scheme *sc, s7_int len, s7_int dims, s7_int *dim_info); /* make-vector but possibly multidimensional */
 s7_pointer s7_make_float_vector_wrapper(s7_scheme *sc, s7_int len, s7_double *data, s7_int dims, s7_int *dim_info, bool free_data);
 s7_pointer s7_make_and_fill_vector(s7_scheme *sc, s7_int len, s7_pointer fill);       /* (make-vector len fill) */
 
@@ -355,7 +366,8 @@ s7_pointer s7_open_input_string(s7_scheme *sc, const char *input_string);
 s7_pointer s7_open_output_string(s7_scheme *sc);                            /* (open-output-string) */
 const char *s7_get_output_string(s7_scheme *sc, s7_pointer out_port);       /* (get-output-string port) -- current contents of output string */
   /*    don't free the string */
-void s7_flush_output_port(s7_scheme *sc, s7_pointer p);                     /* (flush-output-port port) */
+s7_pointer s7_output_string(s7_scheme *sc, s7_pointer p);                   /*    same but returns an s7 string */
+bool s7_flush_output_port(s7_scheme *sc, s7_pointer p);                     /* (flush-output-port port) */
 
 typedef enum {S7_READ, S7_READ_CHAR, S7_READ_LINE, S7_PEEK_CHAR, S7_IS_CHAR_READY, S7_NUM_READ_CHOICES} s7_read_t;
 s7_pointer s7_open_output_function(s7_scheme *sc, void (*function)(s7_scheme *sc, uint8_t c, s7_pointer port));  
@@ -626,6 +638,7 @@ void *s7_c_object_value(s7_pointer obj);
 void *s7_c_object_value_checked(s7_pointer obj, s7_int type);
 s7_pointer s7_make_c_object(s7_scheme *sc, s7_int type, void *value);
 s7_pointer s7_make_c_object_with_let(s7_scheme *sc, s7_int type, void *value, s7_pointer let);
+s7_pointer s7_make_c_object_without_gc(s7_scheme *sc, s7_int type, void *value);
 s7_pointer s7_c_object_let(s7_pointer obj);
 s7_pointer s7_c_object_set_let(s7_scheme *sc, s7_pointer obj, s7_pointer e);
 /* the "let" in s7_make_c_object_with_let and s7_c_object_set_let needs to be GC protected by marking it in the c_object's mark function */
@@ -702,9 +715,9 @@ void s7_c_type_set_setter       (s7_scheme *sc, s7_int tag, s7_pointer setter);
  *   wrapping up the result as a scheme cell.
  */
 
-s7_function s7_optimize(s7_scheme *sc, s7_pointer expr);
+s7_pfunc s7_optimize(s7_scheme *sc, s7_pointer expr);
 
-typedef s7_double (*s7_float_function)(s7_scheme *sc, s7_pointer args);
+typedef s7_double (*s7_float_function)(s7_scheme *sc);
 s7_float_function s7_float_optimize(s7_scheme *sc, s7_pointer expr);
 
 typedef s7_double (*s7_d_t)(void);
@@ -813,7 +826,6 @@ s7_p_d_t s7_p_d_function(s7_pointer f);
  * --------
  */
 
-
 /* -------------------------------------------------------------------------------- */
 
 /* maybe remove these? */
@@ -863,10 +875,6 @@ s7_pointer s7_apply_n_9(s7_scheme *sc, s7_pointer args,
 				       s7_pointer a5, s7_pointer a6, s7_pointer a7, s7_pointer a8, s7_pointer a9));
 
 #if WITH_GMP
-  #include <gmp.h>
-  #include <mpfr.h>
-  #include <mpc.h>
-
   mpfr_t *s7_big_real(s7_pointer x);
   mpz_t  *s7_big_integer(s7_pointer x);
   mpq_t  *s7_big_ratio(s7_pointer x);
@@ -903,7 +911,13 @@ typedef s7_double s7_Double;
 /* --------------------------------------------------------------------------------
  * 
  *        s7 changes
- *
+ * 
+ * 25-Aug:    s7_output_string (like s7_get_output_string, but returns an s7 string).
+ * 19-Jul:    s7_is_random_state, s7_make_normal_vector. s7_array_to_list.
+ * 12-Apr:    s7_optimize now returns an s7_pfunc, not an s7_function.
+ * 7-Apr:     removed the "args" parameter from s7_float_function. added s7_make_c_object_without_gc.
+ * 31-Mar:    vector-rank, vector-dimension.
+ * 17-Mar:    removed deprecated nan.0 and inf.0 due to compiler stupidity.
  * 25-Jan:    s7_define_semisafe_typed_function.
  * 6-Jan-21:  s7_hash_code.
  * --------
