@@ -150,9 +150,10 @@
     (if (and (procedure? bp)
 	     (signature bp)
 	     (eq? 'boolean? (car (signature bp))))
-	(if (type e)
-	    e
-	    (error 'bad-type "~S is ~S but should be ~S" e (type-of e) bp))
+	(let ((result (if (= (car (arity bp)) 1)
+			  (type e)
+			  (bp 'the e))))
+	  (if result e (error 'bad-type "~S is ~S but should be ~S" e (type-of e) bp)))
 	(error 'bad-type "~S is not a boolean procedure" bp))))
 
 (define iota
@@ -207,7 +208,6 @@
     (lambda (obj)
       (pair? (cyclic-sequences obj)))))
 
-
 (define copy-tree
   (let ((+documentation+ "(copy-tree lst) returns a full copy of lst"))
     (lambda (lis)
@@ -394,15 +394,17 @@
 	       (set! result (cons `(set! (setter (quote ,(caar var))) (list-ref ,gsetters ,i)) result))))
        ,@body)))
 
-(define-macro (while test . body)      ; while loop with predefined break and continue
+(define-macro (while test . body)      ; while loop with predefined break and continue.  This really wants to be define-expansion.
   `(call-with-exit
     (lambda (break)
-      (let continue ()
-	(if (let () ,test)
-	    (begin
-	      (let () ,@body)
-	      (continue))
-	    (break))))))
+      (let loop ()
+	(call-with-exit
+	 (lambda (continue)
+	   (do ()
+	       ((not ,test) (break))
+	     ,@body)))
+	(loop)))))
+
 
 (define-macro (do* spec end . body)
   `(let* ,(map (lambda (var)
@@ -1445,57 +1447,14 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 
 ;;; --------------------------------------------------------------------------------
 
-(define (*s7*->list) ;(let->list *s7*) but not using keywords
-  (list
-   :print-length                  (*s7* 'print-length)
-   :safety                        (*s7* 'safety)
-   :debug                         (*s7* 'debug)
-   :profile                       (*s7* 'profile)
-   :cpu-time                      (*s7* 'cpu-time)
-   :heap-size                     (*s7* 'heap-size)
-   :free-heap-size                (*s7* 'free-heap-size)
-   :max-heap-size                 (*s7* 'max-heap-size)
-   :max-port-data-size            (*s7* 'max-port-data-size)
-   :gc-freed                      (*s7* 'gc-freed)
-   :gc-total-freed                (*s7* 'gc-total-freed)
-   :gc-protected-objects          (*s7* 'gc-protected-objects)
-   :gc-stats                      (*s7* 'gc-stats)
-   :gc-temps-size                 (*s7* 'gc-temps-size)
-   :gc-resize-heap-fraction       (*s7* 'gc-resize-heap-fraction)
-   :gc-resize-heap-by-4-fraction  (*s7* 'gc-resize-heap-by-4-fraction)
-   :max-string-length             (*s7* 'max-string-length)
-   :max-list-length               (*s7* 'max-list-length)
-   :max-vector-length             (*s7* 'max-vector-length)
-   :max-vector-dimensions         (*s7* 'max-vector-dimensions)
-   :default-hash-table-length     (*s7* 'default-hash-table-length)
-   :initial-string-port-length    (*s7* 'initial-string-port-length)
-   :output-port-data-size         (*s7* 'output-port-data-size)
-   :default-rationalize-error     (*s7* 'default-rationalize-error)
-   :default-random-state          (*s7* 'default-random-state)
-   :equivalent-float-epsilon      (*s7* 'equivalent-float-epsilon)
-   :hash-table-float-epsilon      (*s7* 'hash-table-float-epsilon)
-   :float-format-precision        (*s7* 'float-format-precision)
-   :bignum-precision              (*s7* 'bignum-precision)
-   :file-names                    (*s7* 'file-names)
-   :rootlet-size                  (*s7* 'rootlet-size)
-   :c-types                       (*s7* 'c-types)
-   :stack-top                     (*s7* 'stack-top)
-   :stack-size                    (*s7* 'stack-size)
-   :stacktrace-defaults           (*s7* 'stacktrace-defaults)
-   :max-stack-size                (*s7* 'max-stack-size)
-   :autoloading?                  (*s7* 'autoloading?)
-   :undefined-identifier-warnings (*s7* 'undefined-identifier-warnings)
-   :undefined-constant-warnings   (*s7* 'undefined-constant-warnings)
-   :accept-all-keyword-arguments  (*s7* 'accept-all-keyword-arguments)
-   :catches                       (*s7* 'catches)
-   :history-size                  (*s7* 'history-size)
-   :history-enabled               (*s7* 'history-enabled)
-   :history                       (*s7* 'history)
-   :openlets                      (*s7* 'openlets)
-   :version                       (*s7* 'version)
-   :most-positive-fixnum          (*s7* 'most-positive-fixnum)
-   :most-negative-fixnum          (*s7* 'most-negative-fixnum)))
-
+(define (*s7*->list) ; (let->list *s7*) flattened and using keywords
+  (do ((p (let->list *s7*) (cdr p)) 
+       (L ()))
+      ((null? p) 
+       (reverse L))
+    (set! L (cons (cdar p) 
+		  (cons (symbol->keyword (caar p))
+			L)))))
 
 
 ;;; --------------------------------------------------------------------------------
@@ -1556,6 +1515,33 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 					   (string-append dir-name "/" file)))))))))))))))))
 
 
+;;; --------------------------------------------------------------------------------
+
+(define (probe-eval val)
+  (let ((probe-let (inlet)))
+    (for-each
+     (lambda (sym)
+       (let ((func (symbol->value sym (rootlet))))
+	 (if (and (procedure? func)
+		  (not (immutable? sym))) ; apply-values etc
+	     (varlet probe-let sym
+		     (lambda args
+		       (let-temporarily (((*s7* 'openlets) #f))
+			 (let ((clean-args (map (lambda (arg)
+						  (if (eq? arg probe-let)
+						      (probe-let 'value)
+						      arg))
+						args)))
+			   (format *stderr* "(~S ~{~S~^ ~})~%" sym clean-args)
+			   (apply func clean-args))))))))
+     (symbol-table))
+    (varlet probe-let 'value val)
+    (openlet probe-let)))
+
+;;(define (call-any x) (+ x 21))
+;;(display (call-any (probe-eval 42))) -> (+ 42 21) 63
+
+
 ;;; --------------------------------------------------------------------------------
 
 (define null-environment
@@ -1574,6 +1560,8 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 ;;; (sandbox '(let ((x 1)) (+ x 2))) -> 3
 ;;; (sandbox '(let ((x 1)) (+ x 2) (exit))) -> #f
 
+;; perhaps tgsl's (immutable-let (rootlet))? 
+
 (define sandbox
   (let ((+documentation+ "(sandbox code) evaluates code in an environment where nothing outside that code can be affected by its evaluation.")
 	(built-ins
@@ -1609,8 +1597,8 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 	      cdddr cdadr cddar caaaar caaadr caadar cadaar caaddr cadddr cadadr caddar cdaaar cdaadr
 	      cdadar cddaar cdaddr cddddr cddadr cdddar assoc member list list-ref list-set! list-tail
 	      make-list length copy fill! reverse reverse! sort! append assq assv memq memv vector-append
-	      list->vector vector-fill! vector-length vector->list vector-ref vector-set! vector-dimensions
-	      make-vector subvector vector float-vector make-float-vector float-vector-set!
+	      list->vector vector-fill! vector-length vector->list vector-ref vector-set! vector-dimension vector-dimensions
+	      make-vector subvector vector float-vector make-float-vector float-vector-set! vector-rank
 	      float-vector-ref int-vector make-int-vector int-vector-set! int-vector-ref string->byte-vector
 	      byte-vector make-byte-vector hash-table make-hash-table hash-table-ref weak-hash-table
 	      hash-table-set! hash-table-entries cyclic-sequences call/cc call-with-current-continuation
