@@ -62,7 +62,7 @@
   "`(ok? ',tst (lambda () (let ((___x #f)) (set! ___x ,tst))) ,expected)"
   "`(ok? ',tst (lambda () (let ((___x #(#f))) (set! (___x 0) ,tst))) ,expected)"
   "`(ok? ',tst (lambda () (let ((___x #(#f))) (vector-set! ___x 0 ,tst))) ,expected)"
-  "`(ok? ',tst (lambda () (dynamic-wind (lambda () #f) (lambda () ,tst) (lambda () #f))) ,expected)"
+  "`(ok? ',tst (lambda () (dynamic-wind #f (lambda () ,tst) #f)) ,expected)"
   "`(ok? ',tst (lambda () (caadr (catch 'receive (lambda () (throw 'receive ,tst)) (lambda any any)))) ,expected)"
   "`(ok? ',tst (lambda () (stacktrace (- (random 100) 50) (- (random 100) 50) (- (random 100) 50) (- (random 100) 50) (> (random 100) 50)) ,tst) ,expected)"
   "`(ok? ',tst (lambda () (let ((__val__ (s7-optimize '(,tst)))) (if (eq? __val__ #<undefined>) ,tst __val__))) ,expected)"
@@ -188,6 +188,9 @@
 (format *stderr* "~NC tmat ~NC~%" 20 #\- 20 #\-)
 (system "./repl tmat.scm")
 
+(format *stderr* "~NC tmac ~NC~%" 20 #\- 20 #\-)
+(system "./repl tmac.scm")
+
 (format *stderr* "~NC teq ~NC~%" 20 #\- 20 #\-)
 (system "./repl teq.scm")
 
@@ -212,6 +215,9 @@
 (format *stderr* "~NC tset ~NC~%" 20 #\- 20 #\-)
 (system "./repl tset.scm")
 
+(format *stderr* "~NC dup ~NC~%" 20 #\- 20 #\-)
+(system "./repl dup.scm")
+
 (format *stderr* "~NC tref ~NC~%" 20 #\- 20 #\-)
 (system "./repl tref.scm")
 
@@ -224,6 +230,9 @@
 (format *stderr* "~NC tvect ~NC~%" 20 #\- 20 #\-)
 (system "./repl tvect.scm")
 
+(format *stderr* "~NC tgsl ~NC~%" 20 #\- 20 #\-)
+(system "./repl tgsl.scm")
+
 (format *stderr* "~NC tio ~NC~%" 20 #\- 20 #\-)
 (system "./repl tio.scm")
 
@@ -245,6 +254,12 @@
 (format *stderr* "~NC tstr ~NC~%" 20 #\- 20 #\-)
 (system "./repl concordance.scm")
 
+(format *stderr* "~NC tlist ~NC~%" 20 #\- 20 #\-)
+(system "./repl tlist.scm")
+
+(format *stderr* "~NC tload ~NC~%" 20 #\- 20 #\-)
+(system "./repl tload.scm")
+
 (format *stderr* "~NC tgc ~NC~%" 20 #\- 20 #\-)
 (system "./repl tgc.scm")
 
@@ -278,4 +293,8 @@
 (format *stderr* "~NC full s7test ~NC~%" 20 #\- 20 #\-)
 (system "./repl full-s7test.scm")
 
+(define with-block #f)
+(format *stderr* "~NC s7test no blocks~NC~%" 20 #\- 20 #\-)
+(system "./repl s7test.scm")
+
 (exit)
