@@ -26,7 +26,6 @@
 (define fft-size (ash 1 17))
 (define little-size 1000000)
 
-
 ;; --------------------------------------------------------------------------------
 (format () "complex fft...~%")
 
@@ -36,7 +35,7 @@
 	 (j 0))
 	((= i n))
       (if (> j i)
-	  (let ((temp (data j)))
+	  (let ((temp (vector-ref data j)))
 	    (vector-set! data j (vector-ref data i))
 	    (vector-set! data i temp)))
       (let ((m (/ n 2)))
@@ -1244,9 +1243,9 @@
 	      (wpi (sin theta))
 	      (wr 1.0)
 	      (wi 0.0)
-	      (wtemp 0.0)
-	      (tempr 0.0)
-	      (tempi 0.0))
+	      (wtemp 0.0+i)
+	      (tempr 0.0+i)
+	      (tempi 0.0+i))
 	  (do ((ii 0 (+ ii 1)))
 	      ((= ii prev))
 	    (do ((i ii (+ i mmax))
@@ -1268,7 +1267,10 @@
 (define (hash-test)
   (let ((fvr (make-hash-table fft-size)) ; (make-hash-table fft-size #t (cons #t float?))
 	(fvi (make-hash-table fft-size))
-	(scl (/ (* 8.0 pi) fft-size)))
+	(scl (/ (* 8.0 pi) fft-size))
+	(vr 0+i)
+	(vi 0+i)
+	(pk 0+i))
     (do ((i 0 (+ i 1))
 	 (x 0.0 (+ x scl)))
 	((= i fft-size))
@@ -1280,12 +1282,12 @@
 	 (i 0 (+ i 1)))
 	((= i fft-size) 
 	 (format () "~A ~A~%" mxloc (/ (* 2 (sqrt mx)) fft-size)))
-      (let* ((vr (hash-table-ref fvr i))
-	     (vi (hash-table-ref fvi i))
-	     (pk (+ (* vr vr) (* vi vi))))
-	(when (> pk mx)
-	  (set! mx pk)
-	  (set! mxloc i))))
+      (set! vr (hash-table-ref fvr i))
+      (set! vi (hash-table-ref fvi i))
+      (set! pk (+ (* vr vr) (* vi vi)))
+      (when (> pk mx)
+	(set! mx pk)
+	(set! mxloc i)))
     (hash-table-set! fvr 4 0.0)
     (hash-table-set! fvi 4 0.0)
     (hash-table-set! fvr (- fft-size 4) 0.0)
@@ -1327,22 +1329,25 @@
 	(let ((wpr (cos theta))
 	      (wpi (sin theta))
 	      (wr 1.0)
-	      (wi 0.0))
+	      (wi 0.0)
+	      (tempr 0.0+i)
+	      (tempi 0.0+i)
+	      (wtemp 0.0+i))
 	  (do ((ii 0 (+ ii 1)))
 	      ((= ii prev))
 	    (do ((i ii (+ i mmax))
 		 (j (+ ii prev) (+ j mmax))
 		 (jj 0 (+ jj 1)))
 		((>= jj pow))
-	      (let ((tempr (- (* wr (hash-table-ref rl (vector-ref rl-syms j))) (* wi (hash-table-ref im (vector-ref im-syms j)))))
-		    (tempi (+ (* wr (hash-table-ref im (vector-ref im-syms j))) (* wi (hash-table-ref rl (vector-ref rl-syms j))))))
-		(hash-table-set! rl (vector-ref rl-syms j) (- (hash-table-ref rl (vector-ref rl-syms i)) tempr))
-		(hash-table-set! rl (vector-ref rl-syms i) (+ (hash-table-ref rl (vector-ref rl-syms i)) tempr))
-		(hash-table-set! im (vector-ref im-syms j) (- (hash-table-ref im (vector-ref im-syms i)) tempi))
-		(hash-table-set! im (vector-ref im-syms i) (+ (hash-table-ref im (vector-ref im-syms i)) tempi))))
-	    (let ((wtemp wr))
-	      (set! wr (- (* wr wpr) (* wi wpi)))
-	      (set! wi (+ (* wi wpr) (* wtemp wpi)))))
+	      (set! tempr (- (* wr (hash-table-ref rl (vector-ref rl-syms j))) (* wi (hash-table-ref im (vector-ref im-syms j)))))
+	      (set! tempi (+ (* wr (hash-table-ref im (vector-ref im-syms j))) (* wi (hash-table-ref rl (vector-ref rl-syms j)))))
+	      (hash-table-set! rl (vector-ref rl-syms j) (- (hash-table-ref rl (vector-ref rl-syms i)) tempr))
+	      (hash-table-set! rl (vector-ref rl-syms i) (+ (hash-table-ref rl (vector-ref rl-syms i)) tempr))
+	      (hash-table-set! im (vector-ref im-syms j) (- (hash-table-ref im (vector-ref im-syms i)) tempi))
+	      (hash-table-set! im (vector-ref im-syms i) (+ (hash-table-ref im (vector-ref im-syms i)) tempi)))
+	    (set! wtemp wr)
+	    (set! wr (- (* wr wpr) (* wi wpi)))
+	    (set! wi (+ (* wi wpr) (* wtemp wpi))))
 	  (set! prev mmax))))
     rl))
 
@@ -1351,7 +1356,10 @@
 	(fvi (hash-table))
 	(rl-syms (make-vector fft-size))
 	(im-syms (make-vector fft-size))
-	(scl (/ (* 8.0 pi) fft-size)))
+	(scl (/ (* 8.0 pi) fft-size))
+	(vr 0+i)
+	(vi 0+i)
+	(pk 0+i))
     (do ((i 0 (+ i 1))
 	 (x 0.0 (+ x scl)))
 	((= i fft-size))
@@ -1365,12 +1373,12 @@
 	 (i 0 (+ i 1)))
 	((= i fft-size) 
 	 (format () "~A ~A~%" mxloc (/ (* 2 (sqrt mx)) fft-size)))
-      (let* ((vr (hash-table-ref fvr (vector-ref rl-syms i)))
-	     (vi (hash-table-ref fvi (vector-ref im-syms i)))
-	     (pk (+ (* vr vr) (* vi vi))))
-	(when (> pk mx)
-	  (set! mx pk)
-	  (set! mxloc i))))
+      (set! vr (hash-table-ref fvr (vector-ref rl-syms i)))
+      (set! vi (hash-table-ref fvi (vector-ref im-syms i)))
+      (set! pk (+ (* vr vr) (* vi vi)))
+      (when (> pk mx)
+	(set! mx pk)
+	(set! mxloc i)))
     (hash-table-set! fvr (vector-ref rl-syms 4) 0.0)
     (hash-table-set! fvi (vector-ref im-syms 4) 0.0)
     (hash-table-set! fvr (vector-ref rl-syms (- fft-size 4)) 0.0)
@@ -1420,22 +1428,25 @@
 	(let ((wpr (cos theta))
 	      (wpi (sin theta))
 	      (wr 1.0)
-	      (wi 0.0))
+	      (wi 0.0)
+	      (tempr 0.0+i)
+	      (tempi 0.0+i)
+	      (wtemp 0.0+i))
 	  (do ((ii 0 (+ ii 1)))
 	      ((= ii prev))
 	    (do ((i ii (+ i mmax))
 		 (j (+ ii prev) (+ j mmax))
 		 (jj 0 (+ jj 1)))
 		((>= jj pow))
-	      (let ((tempr (- (* wr (let-ref rl (vector-ref rl-syms j))) (* wi (let-ref im (vector-ref im-syms j)))))
-		    (tempi (+ (* wr (let-ref im (vector-ref im-syms j))) (* wi (let-ref rl (vector-ref rl-syms j))))))
-		(let-set! rl (vector-ref rl-syms j) (- (let-ref rl (vector-ref rl-syms i)) tempr))
-		(let-set! rl (vector-ref rl-syms i) (+ (let-ref rl (vector-ref rl-syms i)) tempr))
-		(let-set! im (vector-ref im-syms j) (- (let-ref im (vector-ref im-syms i)) tempi))
-		(let-set! im (vector-ref im-syms i) (+ (let-ref im (vector-ref im-syms i)) tempi))))
-	    (let ((wtemp wr))
-	      (set! wr (- (* wr wpr) (* wi wpi)))
-	      (set! wi (+ (* wi wpr) (* wtemp wpi)))))
+	      (set! tempr (- (* wr (let-ref rl (vector-ref rl-syms j))) (* wi (let-ref im (vector-ref im-syms j)))))
+	      (set! tempi (+ (* wr (let-ref im (vector-ref im-syms j))) (* wi (let-ref rl (vector-ref rl-syms j)))))
+	      (let-set! rl (vector-ref rl-syms j) (- (let-ref rl (vector-ref rl-syms i)) tempr))
+	      (let-set! rl (vector-ref rl-syms i) (+ (let-ref rl (vector-ref rl-syms i)) tempr))
+	      (let-set! im (vector-ref im-syms j) (- (let-ref im (vector-ref im-syms i)) tempi))
+	      (let-set! im (vector-ref im-syms i) (+ (let-ref im (vector-ref im-syms i)) tempi)))
+	    (set! wtemp wr)
+	    (set! wr (- (* wr wpr) (* wi wpi)))
+	    (set! wi (+ (* wi wpr) (* wtemp wpi))))
 	  (set! prev mmax))))
     rl))
 
@@ -1444,7 +1455,10 @@
 	(fvi (inlet))
 	(rl-syms (make-vector fft-size))
 	(im-syms (make-vector fft-size))
-	(scl (/ (* 8.0 pi) fft-size)))
+	(scl (/ (* 8.0 pi) fft-size))
+	(vr 0+i)
+	(vi 0+i)
+	(pk 0+i))
     (do ((i 0 (+ i 1))
 	 (x 0.0 (+ x scl)))
 	((= i fft-size))
@@ -1458,12 +1472,12 @@
 	 (i 0 (+ i 1)))
 	((= i fft-size) 
 	 (format () "~A ~A~%" mxloc (/ (* 2 (sqrt mx)) fft-size)))
-      (let* ((vr (let-ref fvr (vector-ref rl-syms i)))
-	     (vi (let-ref fvi (vector-ref im-syms i)))
-	     (pk (+ (* vr vr) (* vi vi))))
-	(when (> pk mx)
-	  (set! mx pk)
-	  (set! mxloc i))))
+      (set! vr (let-ref fvr (vector-ref rl-syms i)))
+      (set! vi (let-ref fvi (vector-ref im-syms i)))
+      (set! pk (+ (* vr vr) (* vi vi)))
+      (when (> pk mx)
+	(set! mx pk)
+	(set! mxloc i)))
     (let-set! fvr (vector-ref rl-syms 4) 0.0)
     (let-set! fvi (vector-ref im-syms 4) 0.0)
     (let-set! fvr (vector-ref rl-syms (- fft-size 4)) 0.0)
@@ -1484,13 +1498,13 @@
 
 (define (string-fft rl im n dir)
   (when rl
-    (let ((tempr 0.0)
-	  (tempi 0.0)
+    (let ((tempr 0.0+i)
+	  (tempi 0.0+i)
 	  (m 0)
 	  (j 0)
 	  (ipw (floor (log n 2)))
 	  (prev 1)
-	  (wtemp 0.0)
+	  (wtemp 0.0+i)
 	  (wpr 0.0)
 	  (wpi 0.0)
 	  (wr 0.0)
@@ -1545,9 +1559,9 @@
 
 (define (string-checker fvr fvi)
   (when fvr
-    (let ((vr 0.0)
-	  (vi 0.0)
-	  (pk 0.0)
+    (let ((vr 0.0+i)
+	  (vi 0.0+i)
+	  (pk 0.0+i)
 	  (mx 0.0)
 	  (mxloc 0))
       (do ((i 0 (+ i 1)))
@@ -1586,19 +1600,18 @@
     (fill! fvi #f)))
 (string-test)
 
-
 (let-temporarily (((*s7* 'float-format-precision) 48))
 (format *stderr* "~%radix...~%")
 (define radix 2)
 (define (string-radix-fft rl im n dir)
   (when rl
-    (let ((tempr 0.0)
-	  (tempi 0.0)
+    (let ((tempr 0.0+i)
+	  (tempi 0.0+i)
 	  (m 0)
 	  (j 0)
 	  (ipw (floor (log n 2)))
 	  (prev 1)
-	  (wtemp 0.0)
+	  (wtemp 0.0+i)
 	  (wpr 0.0)
 	  (wpi 0.0)
 	  (wr 0.0)
@@ -1698,13 +1711,13 @@
 
 (define (port-fft rl im n dir)
   (when rl
-    (let ((tempr 0.0)
-	  (tempi 0.0)
+    (let ((tempr 0.0+i)
+	  (tempi 0.0+i)
 	  (m 0)
 	  (j 0)
 	  (ipw (floor (log n 2)))
 	  (prev 1)
-	  (wtemp 0.0)
+	  (wtemp 0.0+i)
 	  (wpr 0.0)
 	  (wpi 0.0)
 	  (wr 0.0)
@@ -1961,13 +1974,13 @@
 
 (define (iterator-vector-fft rl im n dir)
   (when rl
-    (let ((tempr 0.0)
-	  (tempi 0.0)
+    (let ((tempr 0.0+i)
+	  (tempi 0.0+i)
 	  (m 0)
 	  (j 0)
 	  (ipw (floor (log n 2)))
 	  (prev 1)
-	  (wtemp 0.0)
+	  (wtemp 0.0+i)
 	  (wpr 0.0)
 	  (wpi 0.0)
 	  (wr 0.0)
@@ -2024,9 +2037,9 @@
 
 (define (iterator-vector-checker fvr fvi)
   (when fvr
-    (let ((vr 0.0)
-	  (vi 0.0)
-	  (pk 0.0)
+    (let ((vr 0.0+i)
+	  (vi 0.0+i)
+	  (pk 0.0+i)
 	  (mx 0.0)
 	  (mxloc 0))
       (do ((i 0 (+ i 1)))
@@ -2229,15 +2242,18 @@
     (block-fft fvr fvi fft-size 1)
     (do ((mx 0.0)
 	 (mxloc 0)
+	 (vr 0.0)
+	 (vi 0.0)
+	 (pk 0.0)
 	 (i 0 (+ i 1)))
 	((= i fft-size) 
 	 (format () "~A ~A~%" mxloc (/ (* 2 (sqrt mx)) fft-size)))
-      (let* ((vr (fvr i))
-	     (vi (fvi i))
-	     (pk (+ (* vr vr) (* vi vi))))
-	(when (> pk mx)
-	  (set! mx pk)
-	  (set! mxloc i))))
+      (set! vr (block-ref fvr i))
+      (set! vi (block-ref fvi i))
+      (set! pk (+ (* vr vr) (* vi vi)))
+      (when (> pk mx)
+	(set! mx pk)
+	(set! mxloc i)))
     (set! (fvr 4) 0.0)
     (set! (fvi 4) 0.0)
     (set! (fvr (- fft-size 4)) 0.0)
