@@ -1,4 +1,4 @@
-(set! (*s7* 'heap-size) (* 6 1024000))
+(set! (*s7* 'heap-size) (* 12 1024000))
 
 (define (reader)
   (let ((port (open-input-file "/home/bil/cl/bib"))
@@ -30,21 +30,18 @@
 	    (let ((word (string->symbol (substring line start end))))
 	      (hash-table-set! counts word (+ (or (hash-table-ref counts word) 0) 1)))))
 	(set! new-pos (+ pos 1))))
-    
     (close-input-port port)
-    (let ((res (sort! (copy counts (make-vector (hash-table-entries counts)))
-		      (lambda (a b) (> (cdr a) (cdr b))))))
-      (set! counts #f)
-      res)))
+    (sort! (copy counts (make-vector (hash-table-entries counts)))
+	   (lambda (a b) (> (cdr a) (cdr b))))))
 
 (format *stderr* "reader ")
 
 (let ((counts (reader)))
-  (if (not (and (eq? (car (counts 0)) 'the)
-		(= (cdr (counts 0)) 62063)))
-      (do ((i 0 (+ i 1))) 
-	  ((= i 40)) 
-	(format *stderr* "~A: ~A~%" (car (counts i)) (cdr (counts i))))))
+  (unless (and (eq? (car (counts 0)) 'the)
+	       (= (cdr (counts 0)) 62063))
+    (do ((i 0 (+ i 1))) 
+	((= i 40)) 
+      (format *stderr* "~A: ~A~%" (car (counts i)) (cdr (counts i))))))
 
 ;;; ----------------------------------------
 
@@ -108,7 +105,7 @@
 	  (display "oops")))
     (for-each (lambda (key&value)
 		(unless (= (car key&value) (cdr key&value))
-		    (display "oops"))) ;(format *stderr* "hash iter ~A~%" key&value)))
+		  (display "oops"))) ;(format *stderr* "hash iter ~A~%" key&value)))
 	      (make-iterator int-hash p))
     (set! int-hash #f)))
 
@@ -252,10 +249,10 @@
   (let ((rat-hash (make-hash-table size eqv?)))
     (do ((i 0 (+ i 1))) 
 	((= i size))
-      (hash-table-set! rat-hash (/ i 31) i))
+      (hash-table-set! rat-hash (/ i 3) i))
     (do ((i 0 (+ i 1)))
 	((= i size))
-      (unless (= (hash-table-ref rat-hash (/ i 31)) i)
+      (unless (= (hash-table-ref rat-hash (/ i 3)) i)
 	(display "oops")))
     (set! rat-hash #f)))
 
