@@ -1,6 +1,8 @@
 ;;; various standard benchmarks 
 ;;; --------------------------------------------------------------------------------
 
+(set! (*s7* 'heap-size) 512000)
+
 (define (fannkuch n)
   (call-with-exit
    (lambda (return)
@@ -227,7 +229,7 @@
     (set-cdr! (list-tail increments 7) increments)
     (lambda (z)
       (or (memq z '(2 3 5 7))          ; memv...
-	  (and (positive? (remainder z 2))
+	  (and (odd? z)
 	       (positive? (remainder z 3))	  
 	       (positive? (remainder z 5))	  
 	       (positive? (remainder z 7))
@@ -240,15 +242,18 @@
 		 (set! L (cdr L))))))))
 
 (let ()
-  (define (count-primes limit)          ; for limit=10000000 10.4 secs 664579
-    (let ((primes 0))
-      (do ((i 2 (+ i 1)))
+  (define (count-primes limit)          ; for limit=10M 9.2 secs 664579, 1M .36 secs 78497 (+1 for 1?)
+    (let ((primes 1))
+      (when (even? limit) 
+	(set! limit (+ limit 1)))
+      (do ((i 3 (+ i 2)))
 	  ((= i limit)
 	   primes)
 	(if (prime? i)
 	    (set! primes (+ primes 1))))))
   (display (count-primes 100000)) (newline)) ; 9592
 
+
 ;;; --------------------------------------------------------------------------------
 ;;;
 ;;; spectral-norm, based on code by Anthony Borla (Computer Benchmarks Game)
@@ -326,6 +331,9 @@
 
   (pal-test))
 
+;;; this is 5-6 times faster:
+;;; (define (palindrome? str) (string=? str (reverse str)))
+
 ;;; --------------------------------------------------------------------------------
 
 (when (> (*s7* 'profile) 0)
