@@ -38,6 +38,11 @@
 		     ("tnum.scm" . "v-num")
 		     ("tmock.scm" . "v-mock")
 		     ("concordance.scm" . "v-str")
+		     ("tgsl.scm" . "v-gsl")
+		     ("tlist.scm" . "v-list")
+		     ("tload.scm" . "v-load")
+		     ("cookbook.scm" . "v-cook")
+		     ("tari.scm" . "v-ari")
 		     ))
 
 (define (last-callg)
@@ -71,39 +76,44 @@
 	 (system (format #f "./snd compare-calls.scm -e '(compare-calls \"~A~D\" \"~A~D\")'" outfile (- next 1) outfile next)))))
 
    (list (list "repl" "tpeak.scm")
-	 (list "repl" "tauto.scm")
+	 (list "repl" "tari.scm")
 	 (list "repl" "tref.scm")
+	 (list "repl" "tauto.scm")
 	 (list "repl" "tshoot.scm")
 	 (list "snd -noinit" "make-index.scm")
 	 (list "repl" "tmock.scm")
+	 (list "repl" "tvect.scm")
 	 (list "repl" "s7test.scm")
 	 (list "repl" "lt.scm")
-	 (list "repl" "tcopy.scm")
-	 (list "repl" "tmat.scm")
 	 (list "repl" "tform.scm")
+	 (list "repl" "tmac.scm")
 	 (list "repl" "tread.scm")
-	 (list "repl" "tvect.scm")
 	 (list "repl" "trclo.scm")
 	 (list "repl" "fbench.scm")
+	 (list "repl" "tmat.scm")
+	 (list "repl" "tcopy.scm")
+	 (list "repl" "dup.scm")
 	 (list "repl" "titer.scm")
-	 (list "repl" "tmap.scm")
 	 (list "repl" "tsort.scm")
 	 (list "repl" "tset.scm")
-	 (list "repl" "dup.scm")
-	 (list "repl" "tmac.scm")
-	 (list "repl" "tio.scm")
+	 (list "repl" "tload.scm")
 	 (list "repl" "teq.scm")
-	 (list "repl" "tfft.scm")
+	 (list "repl" "tio.scm")
+	 (list "repl" "concordance.scm")
 	 (list "repl" "tclo.scm")
 	 (list "repl" "tlet.scm")
 	 (list "repl" "tcase.scm")
-	 (list "repl" "concordance.scm")
-	 (list "repl" "trec.scm")
+	 (list "repl" "tmap.scm")
+	 (list "repl" "tfft.scm")
 	 (list "repl" "tnum.scm")
+	 (list "repl" "tgsl.scm")
+	 (list "repl" "trec.scm")
 	 (list "repl" "tmisc.scm")
+	 (list "repl" "tlist.scm")
 	 (list "repl" "tgc.scm")
-	 (list "snd -noinit" "tgen.scm")    ; repl here + cload sndlib was slower
 	 (list "repl" "thash.scm")
+	 (list "repl" "cookbook.scm")
+	 (list "snd -noinit" "tgen.scm")    ; repl here + cload sndlib was slower
 	 (list "snd -noinit" "tall.scm")
 	 (list "snd -l" "snd-test.scm")
 	 (list "snd -l" "full-snd-test.scm")
